@@ -88,15 +88,6 @@ $stats = [
 ?>
 
 <div class="container-fluid">
-    <div class="row">
-        <div class="col-12">
-            <div class="d-flex justify-content-end align-items-center mb-4">
-                <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#targetModal" onclick="clearTargetForm()">
-                    <i class="fa fa-plus"></i> Add Backup Target
-                </button>
-            </div>
-        </div>
-    </div>
 
     <!-- Statistics Cards -->
     <div class="row mb-4">
@@ -233,7 +224,12 @@ $stats = [
         <div class="col-12">
             <div class="card">
                 <div class="card-header">
-                    <h5><i class="fa fa-bullseye"></i> Backup Targets</h5>
+                    <div class="d-flex justify-content-between align-items-center">
+                        <h5 class="mb-0"><i class="fa fa-bullseye"></i> Backup Targets</h5>
+                        <button class="btn btn-primary btn-sm" data-bs-toggle="modal" data-bs-target="#targetModal" onclick="clearTargetForm()">
+                            <i class="fa fa-plus"></i> Add Backup Target
+                        </button>
+                    </div>
                 </div>
                 <div class="card-body">
                     <div class="table-responsive">
